#
# spec file for package wizznic
#
# Copyright (c) 2020 SUSE LLC
# Copyright Vincent Petry <PVince81@yahoo.fr>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wizznic
Version:        1.1
Release:        1.16
Summary:        Implementation of the arcade classic Puzznic
License:        GPL-3.0-only
Group:          Amusements/Games/Board/Puzzle
URL:            http://wizznic.org/
Source0:        https://github.com/DusteDdk/Wizznic/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.desktop
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
%endif
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig(SDL_image)
BuildRequires:  pkgconfig(SDL_mixer)
BuildRequires:  pkgconfig(sdl)

%description
Wizznic is a brick-matching puzzle-game, an improved version of Puzznic.
The challenge is to clear each level of bricks by moving the bricks next
to each other, this sounds a lot easier than it is.
The bricks are heavy, so you can only push them, not lift them up.

%prep
%setup -q -n Wizznic-%{version}

# Correct Permissions
sed -i 's|chmod -R 755|#chmod -R 755|' Makefile.linux

%build
make %{?_smp_mflags} CFLAGS="%{optflags}" DATADIR="%{_datadir}/%{name}/" -f Makefile.linux

%install
make install DESTDIR=%{buildroot} BINDIR=%{_bindir}/ DATADIR=%{_datadir}/%{name}/ -f Makefile.linux

# install icon
install -Dm 0644 data/wmicon.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

# install Desktop file
install -Dm 0644 %{S:1} %{buildroot}%{_datadir}/applications/%{name}.desktop

%if 0%{?suse_version}
    %suse_update_desktop_file %{name}
    %fdupes -s %{buildroot}%{_prefix}
%endif

%files
%doc doc
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/%{name}
%{_datadir}/man/man6/wizznic.6.gz

%changelog
* Thu Sep 10 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.1:
  * Not much to say about this, it's the same good old Wizznic! you know and love.
  * This version only includes some memory-related bugfixes, so if you have
  had bad luck running Wizznic! in the past, give this one a spin!
* Fri Jun 19 2015 dimstar@opensuse.org
- Force GNU inline semantics, fixes build with GCC5.
* Wed Nov  5 2014 nemysis@gmx.ch
- Fix typo
* Wed Nov  5 2014 nemysis@gmx.ch
- Update to 0.9.9, announce message is here:
    https://sourceforge.net/p/wizznic/news/
- Change Summary
- Change URL
- Remove obsolete patches wizznic-linux.patch and
  wizznic-implicit-decl.patch, changed by upstream
- Use BuildRequires pkgconfig(SDL_image), pkgconfig(SDL_mixer) and
  pkgconfig(sdl) instead of SDL-devel, SDL_image-devel and
  SDL_mixer-devel
- Change description
- Correct Permissions
- Simplify installation handling
- Correct what fdupes not have found
- Change Desktop entry file
* Tue Mar 26 2013 joop.boonen@opensuse.org
- Corrected the License
* Sat Nov 19 2011 seife+obs@b1-systems.com
- fix build on 12.1+ (don't require nonexistent licenses package)
- fix the most disgusting "implicit declaration" compiler warnings
  and missing #includes (this obsoletes wizznic-portability.patch
  with a proper fix)
* Sat Jul  2 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel building
- Strip %%clean section (not needed on BS)
* Sat Jan  2 2010 PVince81@yahoo.fr
- Initial package
